searchData={"items":[{"type":"behaviour","title":"Cldr.PersonName","doc":"`ex_cldr_person_names` provides formatting for person names, such as John Smith or 宮崎駿 based upon the [CLDR Person Names](https://www.unicode.org/reports/tr35/tr35-personNames.html) specification. These use patterns to show how a name object (for example, from a database) should be formatted for a particular locale. Name data has fields for the parts of people’s names, such as a given name field with a value of “Maria”, and a surname field value of “Schmidt”.\n\nThere is a wide variety in the way that people’s names appear in different languages.\n\n* People may have a different number of names, depending on their culture—they might have only one name (“Zendaya”), two (“Albert Einstein”), or three or more.\n* People may have multiple words in a particular name field, eg “Mary Beth” as a given name, or “van Berg” as a surname.\n* Some languages, such as Spanish, have two surnames (where each can be composed of multiple words).\n* The ordering of name fields can be different across languages, as well as the spacing (or lack thereof) and punctuation.\n* Name formatting needs to be adapted to different circumstances, such as a need to be presented shorter or longer; formal or informal context; or when talking about someone, or talking to someone, or as a monogram (JFK).\n\nThe `ex_cldr_person_names` functionality is targeted at formatting names for typical usage on computers (e.g. contact names, automated greetings, etc.), rather than being designed for special circumstances or protocol, such addressing royalty. However, the structure may be enhanced in the future when it becomes clear that additional features are needed for some languages.","ref":"Cldr.PersonName.html"},{"type":"behaviour","title":"Not in scope - Cldr.PersonName","doc":"The following features are currently out of scope for Person Names formating:\n\n* Grammatical inflection of formatted names.\n* Context-specific cultural aspects, such as when to use “-san” vs “-sama” when addressing a Japanese person.\n* Providing locale-specific lists of titles, generation terms, and credentials for use in pull-down menus or validation (Mr, Ms., Mx., Dr., Jr., M.D., etc.).\n* Validation of input, such as which fields are required, and what characters are allowed.\n* Combining alternative names, such as multicultural names in Hong Kong \"Jackie Chan Kong-Sang”, or ‘Dwayne “The Rock” Johnson’.\n* More than two levels of formality for names.\n* Parsing of names. \n  * Parsing of name strings into specific name parts such as given and given2. A name like \"Mary Beth Estrella\" could conceivably be any of the following.\n\n  | Given Name\t| Other Given Names | Surname       | Other Surnames  |\n  | ----------  | ----------------- | -------       | --------------  |\n  | Mary\t      | Beth\t            | Estrella      |                 |\t\n  | Mary Beth\t\t|                   | Estrella      |                 |\t\n  | Mary\t\t    |                   | Beth Estrella\t|                 |\n  | Mary\t\t    |                   | Beth\t        | Estrella        |\n\n  * Parsing out the other components of a name in a string, such as surname prefixes (Tussenvoegsel in Dutch).","ref":"Cldr.PersonName.html#module-not-in-scope"},{"type":"behaviour","title":"Structure of a Person Name - Cldr.PersonName","doc":"Person name formatting depends on data supplied by a `t:Cldr.PersonName.t/0` data structure. A `Cldr.PersonName` behaviour and a `Cldr.PersonName.Format` protocol are provided to support easy integration with existing data structures.\n\nThe `t:Cldr.PersonName.t/0` struct is composed of one or more name parts:\n\n* `title` - a string that represents one or more honorifics or titles, such as “Mr.”, or “Herr Doctor”.\n* `given_name` - usually a name given to someone that is not passed to a person by way of parentage.\n* `informal_given_name` - usually either a nickname or a shortened form of the given name that is used to address a person informally.\n* `other_given_names` - name or names that may appear between the first given name string and the surname. In the West, this may be a middle name, in Slavic regions it may be a patronymic name, and in parts of the Middle East, it may be the nasab (نسب) or series of patronymics.\n* `surname_prefix` - in some languages the surname may have a prefix that needs to be treated differently, for example “van den Berg”.\n* `surname` - usually the family name passed to a person that indicates their family, tribe, or community. In most Western languages, this is known as the last name.\n* `other_surnames` - in some cultures, both the parent’s surnames are used and need to be handled separately for formatting in different contexts.\n* `generation` - a string that represents a generation marker, such as “Jr.” or “III”.\n* `credentials` - a string that represents one or more credentials or accreditations, such as “M.D.”, or “MBA”.\n* `locale` - defines the `t.Cldr.LanguageTag.t/0` of a name. This allows different formatting of a name depending on whether it is being formatted for its native locale, or for a different locale.\n* `preferred_order` - an atom indicating the preferred name order for this name. The valid values are `:given_first`, `:surname_first`, `:sorting`. By default, `ex_cldr_person_names` will derive the name order based upon the name's locale and the formatting locale.\n\n**At mininum, a `given_name` is required. All other name attributes are optional**.","ref":"Cldr.PersonName.html#module-structure-of-a-person-name"},{"type":"behaviour","title":"Integration with Existing Data - Cldr.PersonName","doc":"Its clear that existing person name data isn't going to be neatly structured in a `t:Cldr.PersonName.t/0`. `ex_cldr_person_names` provides two mechanisms to integrate existing data:\n\n* The `Cldr.PersonName` behaviour can be used when the developer has control over the data structure, and the data structure is an Elixir `struct`. This is the recommended approach when the developer has control over the struct module. In this case, [callbacks](Cldr.PersonName.html#callbacks) can be implemented for the `struct` that return the person name data to the formatter. The formatter implementation will call `Cldr.PersonName.cast_to_person_name/1` using the callbacks. \n\n* The `Cldr.PersonName.Format` protocol is useful when the developer has no control over the existing data structure. Therefore the `Cldr.PesonName.Format.to_string/2` function can be called and the protocol implementation is expected to craft a structure compatible with - or actually is - a `t:Cldr.PersonName.t/0` struct, and then calls the `Cldr.PersonName.to_string/2` function.  Since `t:Cldr.PersonName.t/0` implements the `Cldr.PersonName.Format` protocol, `Cldr.PersonName.Format.to_string/2` can be used consistently throughout an application if preferred.","ref":"Cldr.PersonName.html#module-integration-with-existing-data"},{"type":"function","title":"Cldr.PersonName.cast_to_person_name/1","doc":"Casts any struct that implements the `Cldr.PersonName`\nbehaviour into a `t:Cldr.PersonName.t/0` struct.","ref":"Cldr.PersonName.html#cast_to_person_name/1"},{"type":"function","title":"Arguments - Cldr.PersonName.cast_to_person_name/1","doc":"* `struct` is any struct that implements the\n  `Cldr.PersonName` behaviour.","ref":"Cldr.PersonName.html#cast_to_person_name/1-arguments"},{"type":"function","title":"Returns - Cldr.PersonName.cast_to_person_name/1","doc":"* A `t:Cldr.PersonName.t/0` struct.","ref":"Cldr.PersonName.html#cast_to_person_name/1-returns"},{"type":"callback","title":"Cldr.PersonName.credentials/1","doc":"Return the credentials as a `t:String.t/0` or `nil` for the given struct","ref":"Cldr.PersonName.html#c:credentials/1"},{"type":"type","title":"Cldr.PersonName.error_message/0","doc":"Standard error response","ref":"Cldr.PersonName.html#t:error_message/0"},{"type":"callback","title":"Cldr.PersonName.generation/1","doc":"Return the generation as a `t:String.t/0` or `nil` for the given struct","ref":"Cldr.PersonName.html#c:generation/1"},{"type":"callback","title":"Cldr.PersonName.given_name/1","doc":"Return the given name as a `t:String.t/0` or `nil` for the given struct","ref":"Cldr.PersonName.html#c:given_name/1"},{"type":"callback","title":"Cldr.PersonName.informal_given_name/1","doc":"Return the informal given name as a `t:String.t/0` or `nil` for the given struct","ref":"Cldr.PersonName.html#c:informal_given_name/1"},{"type":"callback","title":"Cldr.PersonName.locale/1","doc":"Return the locale reference or nil for the given struct","ref":"Cldr.PersonName.html#c:locale/1"},{"type":"function","title":"Cldr.PersonName.new/1","doc":"Returns a `t:Cldr.PersonName.t/0` struct crafted\nfrom a keyword list of attributes.","ref":"Cldr.PersonName.html#new/1"},{"type":"function","title":"Arguments - Cldr.PersonName.new/1","doc":"* `attributes` is a keyword list of person name\n  attributes that is used to contruct a `t:Cldr.PersonName.t/0`.","ref":"Cldr.PersonName.html#new/1-arguments"},{"type":"function","title":"Attributes - Cldr.PersonName.new/1","doc":"* `:given_name` is a persons given name. This is a required\n  attribute. The value is any `t:String.t/0`\n\n* `:title` is a person's title such as \"Mr,\" or \"Dr.\".\n\n* `:other_given_names` is any `t:String.t/0` or `nil`. The\n  default is `nil`.\n\n* `:informal_given_name` is any `t:String.t/0` or `nil`. The\n  default is `nil`.\n\n* `:surname_prefix` is any `t:String.t/0` or `nil`. The\n  default is `nil`.\n\n* `:surname` is any `t:String.t/0` or `nil`. The\n  default is `nil`.\n\n* `:other_surnames` is any `t:String.t/0` or `nil`. The\n  default is `nil`.\n\n* `:generation` is any `t:String.t/0` or `nil`. The\n  default is `nil`.\n\n* `:credentials` is any `t:String.t/0` or `nil`. The\n  default is `nil`.\n\n* `:locale` is any `t:Cldr.LanguageTag.t/0` or nil. The\n  default is `nil`.\n\n* `:backend` is any `Cldr` backend. That is, any module that\n  contains `use Cldr`. This is used to validate the `:locale`\n  only. The default is `Cldr.default_backend!/0`.\n\n* `:name_order` is one of `:given_name`, `:last_name` or\n  `:sorting`. The default is `nil`, meaning that the name order\n  is derived from the name's locale and the formatting locale.","ref":"Cldr.PersonName.html#new/1-attributes"},{"type":"function","title":"Returns - Cldr.PersonName.new/1","doc":"* `{:ok, person_name_struct}` or\n\n* `{:error, reason}`","ref":"Cldr.PersonName.html#new/1-returns"},{"type":"function","title":"Examples - Cldr.PersonName.new/1","doc":"iex> Cldr.PersonName.new(title: \"Mr.\", given_name: \"José\", surname: \"Valim\", credentials: \"Ph.D.\", locale: \"pt\")\n      {:ok,\n       %Cldr.PersonName{\n         title: \"Mr.\",\n         given_name: \"José\",\n         other_given_names: nil,\n         informal_given_name: nil,\n         surname_prefix: nil,\n         surname: \"Valim\",\n         other_surnames: nil,\n         generation: nil,\n         credentials: \"Ph.D.\",\n         preferred_order: nil,\n         locale: AllBackend.Cldr.Locale.new!(\"pt\")\n       }}\n\n      iex> Cldr.PersonName.new(surname: \"Valim\")\n      {:error, \"Person Name requires at least a :given_name\"}","ref":"Cldr.PersonName.html#new/1-examples"},{"type":"callback","title":"Cldr.PersonName.other_given_names/1","doc":"Return the other given names as a `t:String.t/0` or `nil` for the given struct","ref":"Cldr.PersonName.html#c:other_given_names/1"},{"type":"callback","title":"Cldr.PersonName.other_surnames/1","doc":"Return the other surnames as a `t:String.t/0` or `nil` for the given struct","ref":"Cldr.PersonName.html#c:other_surnames/1"},{"type":"callback","title":"Cldr.PersonName.preferred_order/1","doc":"Return the other preferred name order for the given struct","ref":"Cldr.PersonName.html#c:preferred_order/1"},{"type":"callback","title":"Cldr.PersonName.surname/1","doc":"Return the surname as a `t:String.t/0` or `nil` for the given struct","ref":"Cldr.PersonName.html#c:surname/1"},{"type":"callback","title":"Cldr.PersonName.surname_prefix/1","doc":"Return the surname prefix as a `t:String.t/0` or `nil` for the given struct","ref":"Cldr.PersonName.html#c:surname_prefix/1"},{"type":"type","title":"Cldr.PersonName.t/0","doc":"A PersonName struct containing the fields supported\nfor person name formatting.  Any struct that implements\nthe `Cldr.PersonName` behaviour can be converted\nto this struct by calling `Cldr.PersonName.cast_to_person_name/1`.","ref":"Cldr.PersonName.html#t:t/0"},{"type":"callback","title":"Cldr.PersonName.title/1","doc":"Return the title as a `t:String.t/0` or `nil` for the given struct","ref":"Cldr.PersonName.html#c:title/1"},{"type":"function","title":"Cldr.PersonName.to_iodata/2","doc":"Returns a formatted person name as an\n`:erlang.iodata` term.","ref":"Cldr.PersonName.html#to_iodata/2"},{"type":"function","title":"Arguments - Cldr.PersonName.to_iodata/2","doc":"* `person_name` is any struct that implements the\n  `Cldr.PersonName` behaviour, including the native\n  `t:Cldr.PersonName.t/0` struct.\n\n* `options` is a keyword list of options.","ref":"Cldr.PersonName.html#to_iodata/2-arguments"},{"type":"function","title":"Options - Cldr.PersonName.to_iodata/2","doc":"* `:format` is the relative length of a formatted name\n  depending on context. For example, a long formal\n  name in English might include `:title`, `:given_name`,\n  `:other_given_names`, `:surname` plus `:generation` and\n  `:credentials`; whereas a short informal name may only be\n  the `:given_name`. The valid values are `:short`, `:medium`\n  and `:long`. The default is derived from the formatting\n  locales preferences.\n\n* `:usage` indicates if the formatted name is being used\n  to address someone, refer to someone, or present their\n  name in an abbreviated form. The valid values are`:referring`,\n  `:addressing` or `:monogram`. The default is `:referring`. The pattern\n  for `:referring` may be the same as the pattern for\n  `:addressing`.\n\n* `:formality` indicates the formality of usage. A name on a\n  badge for an informal gathering may be much different\n  from an award announcement at the Nobel Prize Ceremonies. The\n  valid values are `:formal` and `:informal`. Note that the\n  formats may be the same for different formality scenarios\n  depending on the length, usage, and cultural conventions\n  for the locale. For example short formal and short\n  informal may both be just the given name. The default is\n  derived from the formatting locale preferences.\n\n* `:order` is used express preference for the orders of attributes\n  in the formatted string. The valid values are `:given_first`,\n  `:surname_first` and `:sorting`. The default is based on features\n  of the person name struct and the formatting locale. The\n  option `:sorting` is only every defined as an option - not the\n  person name or locale data.","ref":"Cldr.PersonName.html#to_iodata/2-options"},{"type":"function","title":"Notes - Cldr.PersonName.to_iodata/2","doc":"The formats may be the same for different lengths\ndepending on the formality, usage, and cultural conventions\nfor the locale.\n\nFor example, medium and short may be the same for a\nparticular context.","ref":"Cldr.PersonName.html#to_iodata/2-notes"},{"type":"function","title":"Returns - Cldr.PersonName.to_iodata/2","doc":"* `{:ok, formatted_name_as_iodata}` or\n\n* `{:error, reason}`.","ref":"Cldr.PersonName.html#to_iodata/2-returns"},{"type":"function","title":"Examples - Cldr.PersonName.to_iodata/2","doc":"iex> {:ok, jose} = Cldr.PersonName.new(title: \"Mr.\", given_name: \"José\", surname: \"Valim\", credentials: \"Ph.D.\", locale: \"pt\")\n    iex> Cldr.PersonName.to_iodata(jose)\n    {:ok, [\"José\"]}\n    iex> Cldr.PersonName.to_iodata(jose, format: :long)\n    {:ok, [\"José\"]}\n    iex> Cldr.PersonName.to_iodata(jose, format: :long, formality: :formal)\n    {:ok, [\"Mr.\", \" \", \"Valim\"]}\n    iex> Cldr.PersonName.to_iodata(jose, format: :long, formality: :formal, usage: :referring)\n    {:ok, [\"Mr.\", \" \", \"José\", \" \", \"Valim\", \" \", \"Ph.D.\"]}","ref":"Cldr.PersonName.html#to_iodata/2-examples"},{"type":"function","title":"Cldr.PersonName.to_iodata!/2","doc":"","ref":"Cldr.PersonName.html#to_iodata!/2"},{"type":"function","title":"Cldr.PersonName.to_string/2","doc":"Returns a formatted person name as an\n`:erlang.iodata` term.","ref":"Cldr.PersonName.html#to_string/2"},{"type":"function","title":"Arguments - Cldr.PersonName.to_string/2","doc":"* `person_name` is any struct that implements the\n  `Cldr.PersonName` behaviour, including the native\n  `t:Cldr.PersonName.t/0` struct.\n\n* `options` is a keyword list of options.","ref":"Cldr.PersonName.html#to_string/2-arguments"},{"type":"function","title":"Options - Cldr.PersonName.to_string/2","doc":"* `:format` is the relative length of a formatted name\n  depending on context. For example, a long formal\n  name in English might include `:title`, `:given_name`,\n  `:other_given_names`, `:surname` plus `:generation` and\n  `:credentials`; whereas a short informal name may only be\n  the `:given_name`. The valid values are `:short`, `:medium`\n  and `:long`. The default is derived from the formatting\n  locales preferences.\n\n* `:usage` indicates if the formatted name is being used\n  to address someone, refer to someone, or present their\n  name in an abbreviated form. The valid values are`:referring`,\n  `:addressing` or `:monogram`. The default is `:referring`. The pattern\n  for `:referring` may be the same as the pattern for\n  `:addressing`.\n\n* `:formality` indicates the formality of usage. A name on a\n  badge for an informal gathering may be much different\n  from an award announcement at the Nobel Prize Ceremonies. The\n  valid values are `:formal` and `:informal`. Note that the\n  formats may be the same for different formality scenarios\n  depending on the length, usage, and cultural conventions\n  for the locale. For example short formal and short\n  informal may both be just the given name. The default is\n  derived from the formatting locale preferences.\n\n* `:order` is used express preference for the orders of attributes\n  in the formatted string. The valid values are `:given_first`,\n  `:surname_first` and `:sorting`. The default is based on features\n  of the person name struct and the formatting locale. The\n  option `:sorting` is only every defined as an option - not the\n  person name or locale data.","ref":"Cldr.PersonName.html#to_string/2-options"},{"type":"function","title":"Notes - Cldr.PersonName.to_string/2","doc":"The formats may be the same for different lengths\ndepending on the formality, usage, and cultural conventions\nfor the locale.\n\nFor example, medium and short may be the same for a\nparticular context.","ref":"Cldr.PersonName.html#to_string/2-notes"},{"type":"function","title":"Returns - Cldr.PersonName.to_string/2","doc":"* `{:ok, formatted_name}` or\n\n* `{:error, reason}`.","ref":"Cldr.PersonName.html#to_string/2-returns"},{"type":"function","title":"Examples - Cldr.PersonName.to_string/2","doc":"iex> {:ok, jose} = Cldr.PersonName.new(title: \"Mr.\", given_name: \"José\", surname: \"Valim\", credentials: \"Ph.D.\", locale: \"pt\")\n    iex> Cldr.PersonName.to_string(jose)\n    {:ok, \"José\"}\n    iex> Cldr.PersonName.to_string(jose, format: :long)\n    {:ok, \"José\"}\n    iex> Cldr.PersonName.to_string(jose, format: :long, formality: :formal)\n    {:ok, \"Mr. Valim\"}\n    iex> Cldr.PersonName.to_string(jose, format: :long, formality: :formal, usage: :referring)\n    {:ok, \"Mr. José Valim Ph.D.\"}","ref":"Cldr.PersonName.html#to_string/2-examples"},{"type":"function","title":"Cldr.PersonName.to_string!/2","doc":"Returns a formatted person name as an\n`:erlang.iodata` term.","ref":"Cldr.PersonName.html#to_string!/2"},{"type":"function","title":"Arguments - Cldr.PersonName.to_string!/2","doc":"* `person_name` is any struct that implements the\n  `Cldr.PersonName` behaviour, including the native\n  `t:Cldr.PersonName.t/0` struct.\n\n* `options` is a keyword list of options.","ref":"Cldr.PersonName.html#to_string!/2-arguments"},{"type":"function","title":"Options - Cldr.PersonName.to_string!/2","doc":"* `:format` is the relative length of a formatted name\n  depending on context. For example, a long formal\n  name in English might include `:title`, `:given_name`,\n  `:other_given_names`, `:surname` plus `:generation` and\n  `:credentials`; whereas a short informal name may only be\n  the `:given_name`. The valid values are `:short`, `:medium`\n  and `:long`. The default is derived from the formatting\n  locales preferences.\n\n* `:usage` indicates if the formatted name is being used\n  to address someone, refer to someone, or present their\n  name in an abbreviated form. The valid values are`:referring`,\n  `:addressing` or `:monogram`. The default is `:referring`. The pattern\n  for `:referring` may be the same as the pattern for\n  `:addressing`.\n\n* `:formality` indicates the formality of usage. A name on a\n  badge for an informal gathering may be much different\n  from an award announcement at the Nobel Prize Ceremonies. The\n  valid values are `:formal` and `:informal`. Note that the\n  formats may be the same for different formality scenarios\n  depending on the length, usage, and cultural conventions\n  for the locale. For example short formal and short\n  informal may both be just the given name. The default is\n  derived from the formatting locale preferences.\n\n* `:order` is used express preference for the orders of attributes\n  in the formatted string. The valid values are `:given_first`,\n  `:surname_first` and `:sorting`. The default is based on features\n  of the person name struct and the formatting locale. The\n  option `:sorting` is only every defined as an option - not the\n  person name or locale data.","ref":"Cldr.PersonName.html#to_string!/2-options"},{"type":"function","title":"Notes - Cldr.PersonName.to_string!/2","doc":"The formats may be the same for different lengths\ndepending on the formality, usage, and cultural conventions\nfor the locale.\n\nFor example, medium and short may be the same for a\nparticular context.","ref":"Cldr.PersonName.html#to_string!/2-notes"},{"type":"function","title":"Returns - Cldr.PersonName.to_string!/2","doc":"* `{:ok, formatted_name}` or\n\n* `{:error, reason}`.","ref":"Cldr.PersonName.html#to_string!/2-returns"},{"type":"function","title":"Examples - Cldr.PersonName.to_string!/2","doc":"iex> {:ok, jose} = Cldr.PersonName.new(title: \"Mr.\", given_name: \"José\", surname: \"Valim\", credentials: \"Ph.D.\", locale: \"pt\")\n    iex> Cldr.PersonName.to_string!(jose)\n    \"José\"\n    iex> Cldr.PersonName.to_string!(jose, format: :long)\n    \"José\"\n    iex> Cldr.PersonName.to_string!(jose, format: :long, formality: :formal)\n    \"Mr. Valim\"\n    iex> Cldr.PersonName.to_string!(jose, format: :long, formality: :formal, usage: :referring)\n    \"Mr. José Valim Ph.D.\"","ref":"Cldr.PersonName.html#to_string!/2-examples"},{"type":"module","title":"Cldr.PersonName.Backend","doc":"","ref":"Cldr.PersonName.Backend.html"},{"type":"function","title":"Cldr.PersonName.Backend.define_person_name_module/1","doc":"","ref":"Cldr.PersonName.Backend.html#define_person_name_module/1"},{"type":"protocol","title":"Cldr.PersonName.Format","doc":"","ref":"Cldr.PersonName.Format.html"},{"type":"type","title":"Cldr.PersonName.Format.t/0","doc":"All the types that implement this protocol.","ref":"Cldr.PersonName.Format.html#t:t/0"},{"type":"function","title":"Cldr.PersonName.Format.to_string/2","doc":"","ref":"Cldr.PersonName.Format.html#to_string/2"},{"type":"function","title":"Cldr.PersonName.Format.to_string!/2","doc":"","ref":"Cldr.PersonName.Format.html#to_string!/2"},{"type":"module","title":"Cldr.PersonName.Formatter","doc":"Implements the person name formatting specification.","ref":"Cldr.PersonName.Formatter.html"},{"type":"function","title":"Cldr.PersonName.Formatter.derive_formatting_locale/3","doc":"","ref":"Cldr.PersonName.Formatter.html#derive_formatting_locale/3"},{"type":"type","title":"Cldr.PersonName.Formatter.formality/0","doc":"Valid :formality option","ref":"Cldr.PersonName.Formatter.html#t:formality/0"},{"type":"type","title":"Cldr.PersonName.Formatter.format/0","doc":"Valid :format option","ref":"Cldr.PersonName.Formatter.html#t:format/0"},{"type":"type","title":"Cldr.PersonName.Formatter.format_option/0","doc":"Valid options for Cldr.PersonName.to_string/2","ref":"Cldr.PersonName.Formatter.html#t:format_option/0"},{"type":"type","title":"Cldr.PersonName.Formatter.format_options/0","doc":"Cldr.PersonName.to_string/2 options list","ref":"Cldr.PersonName.Formatter.html#t:format_options/0"},{"type":"type","title":"Cldr.PersonName.Formatter.name_order/0","doc":"Valid :name_order option","ref":"Cldr.PersonName.Formatter.html#t:name_order/0"},{"type":"type","title":"Cldr.PersonName.Formatter.usage/0","doc":"Valid :usage option","ref":"Cldr.PersonName.Formatter.html#t:usage/0"},{"type":"exception","title":"Cldr.PersonNameError","doc":"Exception raised when person name formatting.","ref":"Cldr.PersonNameError.html"},{"type":"extras","title":"Cldr for Formatting Person Names","doc":"# Cldr for Formatting Person Names\n\n![Build status](https://github.com/elixir-cldr/cldr_person_names/actions/workflows/ci.yml/badge.svg)\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_cldr_person_names.svg)](https://hex.pm/packages/ex_cldr_person_names)\n[![Hex.pm](https://img.shields.io/hexpm/dw/ex_cldr_person_names.svg?)](https://hex.pm/packages/ex_cldr_person_names)\n[![Hex.pm](https://img.shields.io/hexpm/dt/ex_cldr_person_names.svg?)](https://hex.pm/packages/ex_cldr_person_names)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_cldr_person_names.svg)](https://hex.pm/packages/ex_cldr_person_names)","ref":"readme.html"},{"type":"extras","title":"Introduction and Getting Started - Cldr for Formatting Person Names","doc":"`ex_cldr_person_names` is an add-on library for [ex_cldr](https://hex.pm/packages/ex_cldr) that provides localised formatting for peoples' names.  It follows the [CLDR Person Names](https://www.unicode.org/reports/tr35/tr35-personNames.html) specification.","ref":"readme.html#introduction-and-getting-started"},{"type":"extras","title":"Configuration - Cldr for Formatting Person Names","doc":"A backend module must be defined into which the public API and the [CLDR](https://cldr.unicode.org) data is compiled.  See the [ex_cldr documentation](https://hexdocs.pm/ex_cldr/readme.html) for further information on configuration.\n\nIn the following examples we assume the presence of a module called `MyApp.Cldr` defined as:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"fr\"],\n    default_locale: \"en\",\n    providers: [Cldr.PersonName]\nend\n```\n\nNote the `:provider` configuration key which is required to include `Cldr.PersonName` in order for person name formatting to be configured for this backend.","ref":"readme.html#configuration"},{"type":"extras","title":"Installation - Cldr for Formatting Person Names","doc":"Note that `:ex_cldr_person_names` requires Elixir 1.12 or later.\n\nAdd `ex_cldr_person_names` as a dependency to your `mix` project:\n\n    defp deps do\n      [\n        {:ex_cldr_person_names, \"~> 0.1\"}\n      ]\n    end\n\nthen retrieve `ex_cldr_person_names` from [hex](https://hex.pm/packages/ex_cldr_person_names):\n\n    mix deps.get\n    mix deps.compile","ref":"readme.html#installation"},{"type":"extras","title":"Presentations - Cldr for Formatting Person Names","doc":"* Launch presentation at the [Elixir Sydney Meetup](https://www.youtube.com/watch?v=pBR-n_dA3lo) in February 2024.\n* The slides from the launch presetnation are available in [Powerpoint format](https://github.com/elixir-cldr/cldr_person_names/raw/main/presentations/Person%20Name%20Formatting.pptx) and [PDF format](https://github.com/elixir-cldr/cldr_person_names/raw/main/presentations/Person%20Name%20Formatting.pdf)\n\nThe livebook used at the launch presentation is also available.\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fraw.githubusercontent.com%2Felixir-cldr%2Fcldr_person_names%2Fmain%2Flivebooks%2Fperson_name_formatting_explorer.livemd)","ref":"readme.html#presentations"},{"type":"extras","title":"Why Person Name Formatting? - Cldr for Formatting Person Names","doc":"<!-- Split --->\n`ex_cldr_person_names` provides formatting for person names, such as John Smith or 宮崎駿 based upon the [CLDR Person Names](https://www.unicode.org/reports/tr35/tr35-personNames.html) specification. These use patterns to show how a name object (for example, from a database) should be formatted for a particular locale. Name data has fields for the parts of people’s names, such as a given name field with a value of “Maria”, and a surname field value of “Schmidt”.\n\nThere is a wide variety in the way that people’s names appear in different languages.\n\n* People may have a different number of names, depending on their culture—they might have only one name (“Zendaya”), two (“Albert Einstein”), or three or more.\n* People may have multiple words in a particular name field, eg “Mary Beth” as a given name, or “van Berg” as a surname.\n* Some languages, such as Spanish, have two surnames (where each can be composed of multiple words).\n* The ordering of name fields can be different across languages, as well as the spacing (or lack thereof) and punctuation.\n* Name formatting needs to be adapted to different circumstances, such as a need to be presented shorter or longer; formal or informal context; or when talking about someone, or talking to someone, or as a monogram (JFK).\n\nThe `ex_cldr_person_names` functionality is targeted at formatting names for typical usage on computers (e.g. contact names, automated greetings, etc.), rather than being designed for special circumstances or protocol, such addressing royalty. However, the structure may be enhanced in the future when it becomes clear that additional features are needed for some languages.","ref":"readme.html#why-person-name-formatting"},{"type":"extras","title":"Not in scope - Cldr for Formatting Person Names","doc":"The following features are currently out of scope for Person Names formating:\n\n* Grammatical inflection of formatted names.\n* Context-specific cultural aspects, such as when to use “-san” vs “-sama” when addressing a Japanese person.\n* Providing locale-specific lists of titles, generation terms, and credentials for use in pull-down menus or validation (Mr, Ms., Mx., Dr., Jr., M.D., etc.).\n* Validation of input, such as which fields are required, and what characters are allowed.\n* Combining alternative names, such as multicultural names in Hong Kong \"Jackie Chan Kong-Sang”, or ‘Dwayne “The Rock” Johnson’.\n* More than two levels of formality for names.\n* Parsing of names. \n  * Parsing of name strings into specific name parts such as given and given2. A name like \"Mary Beth Estrella\" could conceivably be any of the following.\n\n  | Given Name\t| Other Given Names | Surname       | Other Surnames  |\n  | ----------  | ----------------- | -------       | --------------  |\n  | Mary\t      | Beth\t            | Estrella      |                 |\t\n  | Mary Beth\t\t|                   | Estrella      |                 |\t\n  | Mary\t\t    |                   | Beth Estrella\t|                 |\n  | Mary\t\t    |                   | Beth\t        | Estrella        |\n\n  * Parsing out the other components of a name in a string, such as surname prefixes (Tussenvoegsel in Dutch).","ref":"readme.html#not-in-scope"},{"type":"extras","title":"Structure of a Person Name - Cldr for Formatting Person Names","doc":"Person name formatting depends on data supplied by a `t:Cldr.PersonName.t/0` data structure. A `Cldr.PersonName` behaviour and a `Cldr.PersonName.Format` protocol are provided to support easy integration with existing data structures.\n\nThe `t:Cldr.PersonName.t/0` struct is composed of one or more name parts:\n\n* `title` - a string that represents one or more honorifics or titles, such as “Mr.”, or “Herr Doctor”.\n* `given_name` - usually a name given to someone that is not passed to a person by way of parentage.\n* `informal_given_name` - usually either a nickname or a shortened form of the given name that is used to address a person informally.\n* `other_given_names` - name or names that may appear between the first given name string and the surname. In the West, this may be a middle name, in Slavic regions it may be a patronymic name, and in parts of the Middle East, it may be the nasab (نسب) or series of patronymics.\n* `surname_prefix` - in some languages the surname may have a prefix that needs to be treated differently, for example “van den Berg”.\n* `surname` - usually the family name passed to a person that indicates their family, tribe, or community. In most Western languages, this is known as the last name.\n* `other_surnames` - in some cultures, both the parent’s surnames are used and need to be handled separately for formatting in different contexts.\n* `generation` - a string that represents a generation marker, such as “Jr.” or “III”.\n* `credentials` - a string that represents one or more credentials or accreditations, such as “M.D.”, or “MBA”.\n* `locale` - defines the `t.Cldr.LanguageTag.t/0` of a name. This allows different formatting of a name depending on whether it is being formatted for its native locale, or for a different locale.\n* `preferred_order` - an atom indicating the preferred name order for this name. The valid values are `:given_first`, `:surname_first`, `:sorting`. By default, `ex_cldr_person_names` will derive the name order based upon the name's locale and the formatting locale.\n\n**At mininum, a `given_name` is required. All other name attributes are optional**.","ref":"readme.html#structure-of-a-person-name"},{"type":"extras","title":"Integration with Existing Data - Cldr for Formatting Person Names","doc":"Its clear that existing person name data isn't going to be neatly structured in a `t:Cldr.PersonName.t/0`. `ex_cldr_person_names` provides two mechanisms to integrate existing data:\n\n* The `Cldr.PersonName` behaviour can be used when the developer has control over the data structure, and the data structure is an Elixir `struct`. This is the recommended approach when the developer has control over the struct module. In this case, [callbacks](Cldr.PersonName.html#callbacks) can be implemented for the `struct` that return the person name data to the formatter. The formatter implementation will call `Cldr.PersonName.cast_to_person_name/1` using the callbacks. \n\n* The `Cldr.PersonName.Format` protocol is useful when the developer has no control over the existing data structure. Therefore the `Cldr.PesonName.Format.to_string/2` function can be called and the protocol implementation is expected to craft a structure compatible with - or actually is - a `t:Cldr.PersonName.t/0` struct, and then calls the `Cldr.PersonName.to_string/2` function.  Since `t:Cldr.PersonName.t/0` implements the `Cldr.PersonName.Format` protocol, `Cldr.PersonName.Format.to_string/2` can be used consistently throughout an application if preferred.","ref":"readme.html#integration-with-existing-data"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Cldr Person Names v1.0.0 - Changelog","doc":"This is the changelog for `ex_cldr_person_names` v1.0.0 released on March 18th, 2025.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_person_names/tags)","ref":"changelog.html#cldr-person-names-v1-0-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to [CLDR 47](https://cldr.unicode.org/downloads/cldr-47) data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Person Names v0.2.1 - Changelog","doc":"This is the changelog for `ex_cldr_person_names` v0.2.1 released on December 9th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_person_names/tags)","ref":"changelog.html#cldr-person-names-v0-2-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes `Cldr.PersonName.Formatter.derive_name_locale/2`. Thanks to @peaceful-james for the PR. Closes #1.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Person Names v0.2.0 - Changelog","doc":"This is the changelog for `ex_cldr_person_names` v0.2.0 released on April 24th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_person_names/tags)","ref":"changelog.html#cldr-person-names-v0-2-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix attribute names and validation for `Cldr.PersonName.new/1`\n\n* Fix links in README","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Person Names v0.1.0 - Changelog","doc":"This is the changelog for `ex_cldr_person_names` v0.1.0 released on April 23rd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_person_names/tags)","ref":"changelog.html#cldr-person-names-v0-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Initial release","ref":"changelog.html#enhancements"},{"type":"extras","title":"LICENSE","doc":"","ref":"license.html"},{"type":"extras","title":"License - LICENSE","doc":"Copyright 2023 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}